summaryrefslogtreecommitdiff
path: root/engine/events
diff options
context:
space:
mode:
authorRangi <remy.oukaour+rangi42@gmail.com>2018-03-19 11:36:14 -0400
committerRangi <remy.oukaour+rangi42@gmail.com>2018-03-19 11:36:14 -0400
commit0447ee0cf95d2defb9a202def65288aa5bf1410b (patch)
treedb0a67dcb406514756a94e2a3053b72e105b761e /engine/events
parent12070ca50067d3abe36a730190f88ee43f2cace9 (diff)
Relabel some map-related WRAM
wMisc -> {wSurroundingTiles, wBoxPartialData, wLink_c608} wOverworldMap -> {wOverworldMapBlocks, wHallOfFamePokemonList}
Diffstat (limited to 'engine/events')
-rwxr-xr-xengine/events/battle_tower/battle_tower.asm20
-rwxr-xr-xengine/events/halloffame.asm14
-rwxr-xr-xengine/events/overworld.asm4
-rw-r--r--engine/events/print_unown_2.asm12
4 files changed, 25 insertions, 25 deletions
diff --git a/engine/events/halloffame.asm b/engine/events/halloffame.asm
index cf3831066..b6b547aae 100755
--- a/engine/events/halloffame.asm
+++ b/engine/events/halloffame.asm
@@ -143,12 +143,12 @@ AnimateHallOfFame: ; 864c3
GetHallOfFameParty: ; 8653f
- ld hl, wOverworldMap
- ld bc, HOF_LENGTH
+ ld hl, wHallOfFamePokemonList
+ ld bc, wHallOfFamePokemonListEnd - wHallOfFamePokemonList + 1
xor a
call ByteFill
ld a, [wHallOfFameCount]
- ld de, wOverworldMap
+ ld de, wHallOfFamePokemonList
ld [de], a
inc de
ld hl, wPartySpecies
@@ -216,7 +216,7 @@ GetHallOfFameParty: ; 8653f
pop bc
inc c
pop de
- ld hl, HOF_MON_LENGTH
+ ld hl, wHallOfFamePokemonListMon1End - wHallOfFamePokemonListMon1
add hl, de
ld e, l
ld d, h
@@ -224,7 +224,7 @@ GetHallOfFameParty: ; 8653f
jr .next
.done
- ld a, $ff
+ ld a, -1
ld [de], a
ret
; 865b5
@@ -422,7 +422,7 @@ LoadHOFTeam: ; 8671c
cp NUM_HOF_TEAMS
jr nc, .invalid
ld hl, sHallOfFame
- ld bc, HOF_LENGTH
+ ld bc, wHallOfFameTempEnd - wHallOfFameTemp + 1
call AddNTimes
ld a, BANK(sHallOfFame)
call GetSRAMBank
@@ -430,7 +430,7 @@ LoadHOFTeam: ; 8671c
and a
jr z, .absent
ld de, wHallOfFameTemp
- ld bc, HOF_LENGTH
+ ld bc, wHallOfFameTempEnd - wHallOfFameTemp + 1
call CopyBytes
call CloseSRAM
and a
diff --git a/engine/events/overworld.asm b/engine/events/overworld.asm
index 60ed7cdf9..f9d67f0bd 100755
--- a/engine/events/overworld.asm
+++ b/engine/events/overworld.asm
@@ -179,7 +179,7 @@ CheckMapForSomethingToCut: ; c7ce
farcall CheckCutCollision
pop de
jr nc, .fail
- ; Get the location of the current block in wOverworldMap.
+ ; Get the location of the current block in wOverworldMapBlocks.
call GetBlockLocation
ld c, [hl]
; See if that block contains something that can be cut.
@@ -188,7 +188,7 @@ CheckMapForSomethingToCut: ; c7ce
call CheckOverworldTileArrays
pop hl
jr nc, .fail
- ; Back up the wOverworldMap address to wBuffer3
+ ; Back up the wOverworldMapBlocks address to wBuffer3
ld a, l
ld [wBuffer3], a
ld a, h
diff --git a/engine/events/print_unown_2.asm b/engine/events/print_unown_2.asm
index 78611e594..a2c1f47e3 100644
--- a/engine/events/print_unown_2.asm
+++ b/engine/events/print_unown_2.asm
@@ -12,7 +12,7 @@ RotateUnownFrontpic: ; e0000
ld de, wd002
call .Copy
call .Rotate
- ld hl, UnownPrinter_OverworldMapRectangle
+ ld hl, UnownPrinter_GBPrinterRectangle
pop bc
add hl, bc
add hl, bc
@@ -30,7 +30,7 @@ RotateUnownFrontpic: ; e0000
cp 7 * 7
jr c, .loop
- ld hl, wOverworldMap
+ ld hl, wGameboyPrinterRAM
ld de, sScratch
ld bc, 7 * 7 tiles
call CopyBytes
@@ -95,17 +95,17 @@ RotateUnownFrontpic: ; e0000
jr nz, .loop_count
ret
-overworldmaprect: MACRO
+gbprinterrect: MACRO
y = 0
rept \1
x = \1 * (\2 + -1) + y
rept \2
- dw wOverworldMap tile x
+ dw wGameboyPrinterRAM tile x
x = x + -\2
endr
y = y + 1
endr
ENDM
-UnownPrinter_OverworldMapRectangle: ; e008b
- overworldmaprect 7, 7
+UnownPrinter_GBPrinterRectangle: ; e008b
+ gbprinterrect 7, 7
diff --git a/engine/events/battle_tower/battle_tower.asm b/engine/events/battle_tower/battle_tower.asm
index 9dace59b4..d2e3b1c4c 100755
--- a/engine/events/battle_tower/battle_tower.asm
+++ b/engine/events/battle_tower/battle_tower.asm
@@ -64,7 +64,7 @@ Function170114: ; 170114
ld a, $5
call GetSRAMBank
ld hl, $a948
- ld de, wMisc
+ ld de, wc608
ld bc, $f6 ; 246
call CopyBytes
call CloseSRAM
@@ -90,11 +90,11 @@ Function170139: ; 170139
ld b, $0
add hl, bc
call CloseSRAM
; Store that number in wMisc
ld a, h
- ld [wMisc], a
+ ld [wc608], a
ld a, l
- ld [wMisc + 1], a
+ ld [wc608 + 1], a
ld hl, wBT_OTTempMon1DVs
ld a, [wPlayerID]
ld [hli], a
@@ -161,7 +161,7 @@ Function170139: ; 170139
ld hl, $a894
ld bc, NAME_LENGTH_JAPANESE
call CopyBytes
- ld hl, wMisc
+ ld hl, wc608
ld de, $a948
ld bc, $f6
call CopyBytes
@@ -674,7 +674,7 @@ Function1704e1: ; 1704e1
call CopyBytes
ld hl, $a8b2
- ld de, wMisc
+ ld de, wc608
ld bc, $0096
call CopyBytes
@@ -793,7 +793,7 @@ Function1704e1: ; 1704e1
call .PlaceUpDownArrows
ld a, $50
ld [wcd4e], a
- ld hl, wMisc
+ ld hl, wc608
ld a, [wNrOfBeatenBattleTowerTrainers]
ld c, a
xor a
@@ -1441,7 +1441,7 @@ Function1709bb: ; 1709bb (5c:49bb) BattleTowerAction $10
ld a, $5
call GetSRAMBank
ld hl, $b023
- ld de, wMisc
+ ld de, wc608
ld bc, $0069
call CopyBytes
ld a, [$a825]
@@ -1460,14 +1460,14 @@ Function1709bb: ; 1709bb (5c:49bb) BattleTowerAction $10
ld a, $0
call GetSRAMBank
ld hl, wRTC
- ld de, wMisc
+ ld de, wc608
ld bc, $0004
call CopyBytes
call CloseSRAM
ld a, $5
call GetSRAMBank
ld hl, $b08c
- ld de, wMisc
+ ld de, wc608
ld c, $4
.compare_loop
ld a, [de]
@@ -90,11 +90,11 @@ Function170139: ; 170139
add hl, bc
call CloseSRAM
-; Store that number in wMisc
+; Store that number in wc608
ld a, h